# Automatically generated by Pynguin.
import pylexique as module0


def test_case_0():
    var0 = module0.Lexique383()
    var1 = var0.__repr__()


def test_case_1():
    var0 = module0.Lexique383()
    var1 = var0.__repr__()
    var2 = var0.__len__()


def test_case_2():
    var0 = module0.Lexique383()
    var1 = var0.__repr__()
    var2 = "q'\r5jRbq1eJN=L"
    var3 = [var2, var2, var2]
    var4 = module0.LexItem(var3)
    var5 = var4.__repr__()


def test_case_3():
    var0 = module0.Lexique383()
    var1 = var0.__repr__()
    var2 = module0.Lexique383()
    var3 = var2.__repr__()
    var4 = "q'\r5jRbq1eJN=L"
    var5 = [var4, var4, var4]
    var6 = module0.LexItem(var5)
    var7 = var6.__repr__()
    var8 = module0.Lexique383()
    var9 = var8.__repr__()
    var10 = var8.__len__()
    var11 = var8.__repr__()


def test_case_4():
    var0 = module0.Lexique383()
    var1 = var0.__repr__()
    var2 = module0.Lexique383()
    var3 = var2.__repr__()
    var4 = "q'\r5jRbq1eJN=L"
    var5 = [var4, var4, var4]
    var6 = module0.LexItem(var5)
    var7 = var6.__repr__()
    var8 = module0.Lexique383()
    var9 = var8.__repr__()
    var10 = var8.__len__()
    var11 = var6.to_dict()


def test_case_5():
    var0 = module0.Lexique383()
    var1 = var0.__repr__()
    var2 = module0.LexEntryTypes()



# Automatically generated by Pynguin.
import pylexique as module0


def test_case_0():
    try:
        var0 = []
        var1 = module0.LexItem(var0)
    except BaseException:
        pass


def test_case_1():
    try:
        var0 = []
        var1 = module0.LexItem(var0)
    except BaseException:
        pass


def test_case_2():
    try:
        var0 = '25,86'
        var1 = module0.Lexique383(var0)
    except BaseException:
        pass



import pytest
from pylexique import Lexique383
from pprint import pprint
import pkg_resources



class TestAll:
    def test_all(self):
        # Assigns resource paths
        _RESOURCE_PACKAGE = 'pylexique'
        _RESOURCE_PATH = pkg_resources.resource_filename(_RESOURCE_PACKAGE, 'Lexique383/Lexique383.txt')
        _RESOURCE_PICKLE_PATH = pkg_resources.resource_filename(_RESOURCE_PACKAGE, 'Lexique383/Lexique383.pkl')

        #  Create new Lexique383 instance with a pre-built Lexique383.
        LEXIQUE = Lexique383()

        # Creates a new Lexique383 instance while supplying your own Lexique38X lexicon. The first time it will it will be
        # slow to parse the file and create a persistent data-store. Next runs should be much faster.
        # LEXIQUE2 = Lexique383(_RESOURCE_PATH)

        # There are 2 ways to access the lexical information of a word:
        # Either use the utility method Lexique383.get_lex(item)
        # Or you an directly access the lexicon directory through LEXIQUE.lexique[item] .

        # Notice that item can be either a string or a sequence of strings when using Lexique383.get_lex(item) .


        #  Retrieves the lexical information of 'abaissait' and 'a'.
        var_1 = LEXIQUE.lexique['abaissait']
        var_1_bis = LEXIQUE.get_lex('abaissait')

        # Check both objects are the same
        var_1_equality = var_1 == var_1_bis['abaissait']
        print(var_1_equality)

        # Because in French the world 'a' is very polysemic word, it has several entries in Lexique 383.
        # For this reason the LEXIQUE Dict has the value of the `ortho` property of its LexicalEntry.
        # In th case of 'abaissait' there is only one LexicalItem corresponding to this dist key.
        # But in the case of 'a' there are several LexItem objects corresponding to this key and then the LexItem objects
        # are stored in a list corresponding to th value of the key.
        var_2 = LEXIQUE.lexique['a']
        var_2_bis = LEXIQUE.get_lex('a')

        # Check both objects are the same
        var_2_equality = var_2 == var_2_bis['a']
        print(var_2_equality)

        # Retrieving the lexical information of several words by passing a Sequence of strings

        var_multiple = LEXIQUE.get_lex(('il', 'mange', 'une', 'baguette'))
        pprint(var_multiple)

        # You can use the method LexItem.to_dict() to produce a dictionary with key/value pairs corresponding to the LexItem

        print('\n\n')
        if isinstance(var_1, list):
            for elmt in var_1:
                pprint(elmt.to_dict())
                print('\n\n')
        else:
            pprint(var_1.to_dict())
            print('\n\n')

        print('\n\n')
        if isinstance(var_2, list):
            for elmt in var_2:
                pprint(elmt.to_dict())
                print('\n\n')
        else:
            pprint(var_2.to_dict())
            print('\n\n')

        # Get all verbs in the DataSet. Because some words have the same orthography, some keys of the dictionary
        # don't have a unique LexItem object as their value, but a list of those.
        verbs = []
        for x in LEXIQUE.lexique.values():
            if isinstance(x, list):
                for y in x:
                    if not isinstance(y, list) and y.cgram == 'VER':
                        verbs.append(y)
            elif x.cgram == 'VER':
                verbs.append(x)
            else:
                continue

        print('Printing the first 5 verbs found in the preceding search:')
        pprint(verbs[0:5])

        # Print the first 5 verbs with full lexical information.
        for verb in verbs[0:5]:
            pprint(verb.to_dict())
        pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for `pylexique` package."""

import pytest
from collections import OrderedDict
from dataclasses import asdict
from click.testing import CliRunner

from pylexique import Lexique383

from pylexique import pylexique, cli


def test_content():
    """Sample pytest test of pylexique."""
    others = []
    lexicon = Lexique383()
    x = 'a posteriori'
    if x in lexicon.lexique:
        if isinstance(lexicon.lexique[x], list ):
            for elmnt in lexicon.lexique[x]:
                if elmnt.cgram == 'ADV':
                    assert elmnt.cgram == 'ADV'
        elif lexicon.lexique[x].cgram == 'ADV':
            assert lexicon.lexique[x].cgram == 'ADV'
        else:
            others.append(x)


def test_command_line_interface():
    """Test the CLI for ."""
    runner = CliRunner()
    result = runner.invoke(cli.main)
    assert result.exit_code == 0
    help_result = runner.invoke(cli.main, ['--help'])
    assert help_result.exit_code == 0
    assert 'Pylexique is a Python wrapper around Lexique83.' in help_result.output
